@@ -6,7 +6,10 @@ from netbox_storage.api.views import (
     FilesystemViewSet,
     PartitionViewSet,
     MountedVolumeViewSet,
-    LinuxDeviceViewSet
+    LinuxDeviceViewSet,
+    LogicalVolumeViewSet,
+    PhysicalVolumeViewSet,
+    VolumeGroupViewSet
 )
 
 router = NetBoxRouter()
@@ -17,5 +20,8 @@ router.register("filesystem", FilesystemViewSet)
 router.register("partition", PartitionViewSet)
 router.register("mountedvolume", MountedVolumeViewSet)
 router.register("linuxdevice", LinuxDeviceViewSet)
+router.register("logicalvolume", LogicalVolumeViewSet)
+router.register("physicalvolume", PhysicalVolumeViewSet)
+router.register("volumegroup", VolumeGroupViewSet)
 
 urlpatterns = router.urls
