@@ -29,7 +29,7 @@ class LogicalVolumeForm(NetBoxModelForm):
         help_text="Volume Group Name e.g. vg_docker",
     )
     size = FloatField(
-        label="Size (MB)",
+        label="Size (GB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
