@@ -101,6 +101,10 @@ class Drive(NetBoxModel):
     def partition_count(self):
         return Partition.objects.filter(drive=self).count()
 
+    def free_space_on_drive(self):
+        print(f"Free Space: {Partition.objects.filter(drive=self).aggregate(Sum('size'))}")
+        return 0
+
     def device_name(self):
         return f'/dev/sd{chr(ord("`") + int(self.identifier[-1]))}'
 
