@@ -51,6 +51,7 @@ class PlatformTemplateContent(PluginTemplateExtension):
             partition_dict = {}
             for drive_id in drives_id:
                 drive = Drive.objects.get(pk=drive_id['drive'])
+                print(f"{drive.free_space_on_drive}")
                 if Partition.objects.filter(drive=drive).count() == 0:
                     partition_dict[drive] = None
                 else:
@@ -91,38 +92,19 @@ class PlatformTemplateContent(PluginTemplateExtension):
             )
 
     def left_page(self):
-        mounted_volumes = MountedVolume.objects.all()
-        return self.render(
-            "netbox_storage/inc/template_volume_box.html",
-            extra_context={
-                "mounted_volumes": mounted_volumes
-            }
-        )
-
-    def full_width_page(self):
         obj = self.context.get("object")
-
-        drives = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
-        drives_id = []
-        lonely_drive = []
-        linux_devices = []
-        for drive_id in drives:
-            drives_id.append(drive_id['drive'])
-            # if LinuxDevice.objects.filter(linux_device_drives=drive_id['drive']).count() == 0:
-            drive = Drive.objects.get(pk=drive_id['drive'])
-            lonely_drive.append(drive)
-#                print(LinuxDevice.objects.filter(linux_device_drives=drive_id['drive']))
-
-        partitions = Partition.objects.filter(drive_id__in=drives_id)
-
-        return self.render(
-            "netbox_storage/inc/template_volume_box.html",
-            extra_context={
-                "lonely_drives": lonely_drive,
-                "partitions": partitions,
-                "linux_devices": linux_devices
-            }
-        )
+        mounted_volumes = MountedVolume.objects.all()
+        if obj.name.lower().__contains__('windows'):
+            return self.render(
+                "netbox_storage/inc/nothing.html",
+            )
+        else:
+            return self.render(
+                "netbox_storage/inc/template_volume_box.html",
+                extra_context={
+                    "mounted_volumes": mounted_volumes
+                }
+            )
 
 
 template_extensions = [VMTemplateContent, PlatformTemplateContent]
