@@ -1,5 +1,5 @@
 from .drive import *
 from .filesystem import *
-from .linux_volume import *
+from .mounted_volume import *
 from .partition import *
 from .simple import *
